@@ -57,3 +57,14 @@ cp $NMSTATE_PATH/deploy/examples/nmstate.io_*_nmstate_cr.yaml data/nmstate/opera
 
 echo 'Apply custom CNAO patches on kubernetes-nmstate manifests'
 sed -i -z 's#kind: Secret\nmetadata:#kind: Secret\nmetadata:\n  annotations:\n    networkaddonsoperator.network.kubevirt.io\/rejectOwner: ""#' data/nmstate/operand/operator.yaml
+sed -i -z 's#metadata:\n#metadata:\n  annotations:\n    networkaddonsoperator.network.kubevirt.io\/rejectOwner: ""\n#' data/nmstate/operator/nmstate.io_*_nmstate_cr.yaml
+cat <<EOF >> data/nmstate/operator/nmstate.io_*_nmstate_cr.yaml
+spec:
+  nodeSelector: {{ toYaml .HandlerNodeSelector | nindent 4 }}
+  handlerTolerations: {{ toYaml .HandlerTolerations | nindent 4 }}
+  affinity: {{ toYaml .HandlerAffinity | nindent 4 }}
+  infraNodeSelector: {{ toYaml .InfraNodeSelector | nindent 4 }}
+  infraTolerations: {{ toYaml .InfraTolerations | nindent 4 }}
+  infraAffinity: {{ toYaml .InfraAffinity | nindent 4 }}
+  selfSignConfiguration : {{ toYaml .SelfSignConfiguration | nindent 4 }}
+EOF
