@@ -28,14 +28,21 @@ func renderNMState(conf *cnao.NetworkAddonsConfigSpec, manifestDir string, clust
 	}
 
 	confWithDefaults := pupulateNmstateDefaultConfiguration(conf)
-
+	selfSignConfiguration := conf.SelfSignConfiguration
+	if selfSignConfiguration == nil {
+		selfSignConfiguration = &cnao.SelfSignConfiguration{
+			CARotateInterval:    "8760h0m0s",
+			CAOverlapInterval:   "24h0m0s",
+			CertRotateInterval:  "4380h0m0s",
+			CertOverlapInterval: "24h0m0s",
+		}
+	}
 	// render the manifests on disk
 	data := render.MakeRenderData()
 	data.Data["HandlerPrefix"] = ""
 	data.Data["HandlerNamespace"] = os.Getenv("OPERAND_NAMESPACE")
 	data.Data["HandlerImage"] = os.Getenv("NMSTATE_HANDLER_IMAGE")
 	data.Data["HandlerPullPolicy"] = confWithDefaults.ImagePullPolicy
-	data.Data["HandlerNodeSelector"] = map[string]string{}
 	data.Data["EnableSCC"] = clusterInfo.SCCAvailable
 	data.Data["CARotateInterval"] = confWithDefaults.SelfSignConfiguration.CARotateInterval
 	data.Data["CAOverlapInterval"] = confWithDefaults.SelfSignConfiguration.CAOverlapInterval
@@ -44,6 +51,13 @@ func renderNMState(conf *cnao.NetworkAddonsConfigSpec, manifestDir string, clust
 	data.Data["PlacementConfiguration"] = confWithDefaults.PlacementConfiguration
 	data.Data["WebhookReplicas"] = getNumberOfWebhookReplicas(clusterInfo)
 	data.Data["WebhookMinReplicas"] = getMinNumberOfWebhookReplicas(clusterInfo)
+	data.Data["HandlerNodeSelector"] = confWithDefaults.PlacementConfiguration.Workloads.NodeSelector
+	data.Data["HandlerTolerations"] = confWithDefaults.PlacementConfiguration.Workloads.Tolerations
+	data.Data["HandlerAffinity"] = confWithDefaults.PlacementConfiguration.Workloads.Affinity
+	data.Data["InfraNodeSelector"] = confWithDefaults.PlacementConfiguration.Infra.NodeSelector
+	data.Data["InfraTolerations"] = confWithDefaults.PlacementConfiguration.Infra.Tolerations
+	data.Data["InfraAffinity"] = confWithDefaults.PlacementConfiguration.Infra.Affinity
+	data.Data["SelfSignConfiguration"] = selfSignConfiguration
 
 	_, enableOVS := os.LookupEnv("NMSTATE_ENABLE_OVS")
 	data.Data["EnableOVS"] = enableOVS
