@@ -10,10 +10,10 @@ import (
 	"text/template"
 	"time"
 
-	framework "github.com/operator-framework/operator-sdk/pkg/test"
 	"github.com/pkg/errors"
 	v1 "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
+	apierrors "k8s.io/apimachinery/pkg/api/errors"
 	"k8s.io/apimachinery/pkg/runtime/schema"
 	"k8s.io/apimachinery/pkg/types"
 	"k8s.io/client-go/util/retry"
@@ -26,6 +26,7 @@ import (
 	"github.com/kubevirt/cluster-network-addons-operator/pkg/components"
 	"github.com/kubevirt/cluster-network-addons-operator/pkg/network"
 	. "github.com/kubevirt/cluster-network-addons-operator/test/check"
+	testenv "github.com/kubevirt/cluster-network-addons-operator/test/env"
 	"github.com/kubevirt/cluster-network-addons-operator/test/kubectl"
 	. "github.com/kubevirt/cluster-network-addons-operator/test/operations"
 )
@@ -377,11 +378,11 @@ var _ = Describe("NetworkAddonsConfig", func() {
 				By("Setting a new Annotation to the macvtap daemonSet")
 				err := retry.RetryOnConflict(retry.DefaultRetry, func() error {
 					macvtapDaemonSet := &v1.DaemonSet{}
-					err := framework.Global.Client.Get(context.TODO(), types.NamespacedName{Name: MacvtapComponent.DaemonSets[0], Namespace: components.Namespace}, macvtapDaemonSet)
+					err := testenv.Client.Get(context.TODO(), types.NamespacedName{Name: MacvtapComponent.DaemonSets[0], Namespace: components.Namespace}, macvtapDaemonSet)
 					Expect(err).ToNot(HaveOccurred(), "should succeed getting the macvtap daemonSet")
 
 					macvtapDaemonSet.Spec.Template.SetAnnotations(map[string]string{annotationKey: ""})
-					return framework.Global.Client.Update(context.TODO(), macvtapDaemonSet)
+					return testenv.Client.Update(context.TODO(), macvtapDaemonSet)
 				})
 				Expect(err).ToNot(HaveOccurred(), "should succeed setting a new Annotation to the macvtap daemonSet")
 			})
@@ -390,7 +391,7 @@ var _ = Describe("NetworkAddonsConfig", func() {
 				By("checking that the Annotation eventually removed reconciled out by the CNAO operator")
 				Eventually(func() bool {
 					macvtapDaemonSet := &v1.DaemonSet{}
-					err := framework.Global.Client.Get(context.TODO(), types.NamespacedName{Name: MacvtapComponent.DaemonSets[0], Namespace: components.Namespace}, macvtapDaemonSet)
+					err := testenv.Client.Get(context.TODO(), types.NamespacedName{Name: MacvtapComponent.DaemonSets[0], Namespace: components.Namespace}, macvtapDaemonSet)
 					Expect(err).ToNot(HaveOccurred(), "should succeed getting the macvtap daemonSet")
 
 					deamonSetAnnotations := macvtapDaemonSet.Spec.Template.GetAnnotations()
@@ -412,33 +413,31 @@ var _ = Describe("NetworkAddonsConfig", func() {
 				NMState: &cnao.NMState{},
 			}
 		})
-		JustBeforeEach(func() {
-			// Install nmstate-operator here
-			installNMStateOperator()
-			CheckNMStateOperatorIsReady(5 * time.Minute)
+		Context("with nmstate-operator installed", func() {
+			JustBeforeEach(func() {
+				// Install nmstate-operator here
+				installNMStateOperator()
+				CheckNMStateOperatorIsReady(5 * time.Minute)
 
-			CreateConfig(gvk, configSpec)
-			CheckConfigCondition(gvk, ConditionAvailable, ConditionTrue, 15*time.Minute, CheckDoNotRepeat)
-		})
-		JustAfterEach(func() {
-			uninstallNMStateOperator()
-		})
-		Context("when it is already deployed", func() {
-			Context("and the nmstate-operator is installed", func() {
+				CreateConfig(gvk, configSpec)
+				CheckConfigCondition(gvk, ConditionAvailable, ConditionTrue, 15*time.Minute, CheckDoNotRepeat)
+			})
+			JustAfterEach(func() {
+				uninstallNMStateOperator()
+			})
+			Context("when it is already deployed", func() {
 				It("should run nmstate from the operator", func() {
 					By("checking for NMState in nmstate namespace")
 					Eventually(func() error {
 						nmstateHandlerDaemonSet := &v1.DaemonSet{}
-						return framework.Global.Client.Get(context.TODO(), types.NamespacedName{Name: NMStateComponent.DaemonSets[0], Namespace: "nmstate"}, nmstateHandlerDaemonSet)
+						return testenv.Client.Get(context.TODO(), types.NamespacedName{Name: NMStateComponent.DaemonSets[0], Namespace: "nmstate"}, nmstateHandlerDaemonSet)
 					}, 5*time.Minute, time.Second).Should(BeNil(), fmt.Sprintf("Timed out waiting for nmstate-operator daemonset"))
 				})
 			})
-		})
-		Context("when it is not already deployed", func() {
-			BeforeEach(func() {
-				configSpec = cnao.NetworkAddonsConfigSpec{}
-			})
-			Context("and the nmstate-operator is installed", func() {
+			Context("when it is not already deployed", func() {
+				BeforeEach(func() {
+					configSpec = cnao.NetworkAddonsConfigSpec{}
+				})
 				It("should run nmstate from the operator", func() {
 					configSpec = cnao.NetworkAddonsConfigSpec{
 						NMState: &cnao.NMState{},
@@ -448,8 +447,56 @@ var _ = Describe("NetworkAddonsConfig", func() {
 					By("checking for NMState in nmstate namespace")
 					Eventually(func() error {
 						nmstateHandlerDaemonSet := &v1.DaemonSet{}
-						return framework.Global.Client.Get(context.TODO(), types.NamespacedName{Name: NMStateComponent.DaemonSets[0], Namespace: "nmstate"}, nmstateHandlerDaemonSet)
-					}, 5*time.Minute, time.Second).Should(BeNil(), fmt.Sprintf("Timed out waiting for nmstate-operator daemonset"))
+						return testenv.Client.Get(context.TODO(), types.NamespacedName{Name: NMStateComponent.DaemonSets[0], Namespace: "nmstate"}, nmstateHandlerDaemonSet)
+					}, 5*time.Minute, time.Second).Should(BeNil(), "Timed out waiting for nmstate-operator daemonset")
+				})
+			})
+		})
+		Context("without nmstate-operator pre-installed", func() {
+			BeforeEach(func() {
+				By("Deploying Nmstate")
+				config := cnao.NetworkAddonsConfigSpec{NMState: &cnao.NMState{}}
+				CreateConfig(gvk, config)
+			})
+			It("should deploy nmstate via CNAO", func() {
+				CheckConfigCondition(gvk, ConditionAvailable, ConditionTrue, 15*time.Minute, CheckDoNotRepeat)
+			})
+			Context("when nmstate-operator is then installed", func() {
+				BeforeEach(func() {
+					installNMStateOperator()
+					CheckNMStateOperatorIsReady(5 * time.Minute)
+				})
+				AfterEach(func() {
+					uninstallNMStateOperator()
+				})
+				It("should switch nmstate from CNAO deployment to nmstate-operator deployment", func() {
+					By("checking for NMState in CNAO namespace")
+					cnaoNmstateHandlerNotFound := func() bool {
+						nmstateHandlerDaemonSet := &v1.DaemonSet{}
+						err := testenv.Client.Get(context.TODO(), types.NamespacedName{Name: NMStateComponent.DaemonSets[0], Namespace: "cluster-network-addons"}, nmstateHandlerDaemonSet)
+						return apierrors.IsNotFound(err)
+					}
+					Eventually(func() bool {
+						return cnaoNmstateHandlerNotFound()
+					}, 5*time.Minute, time.Second).Should(BeTrue(), "Timed out waiting for CNAO nmstate deployment to be removed")
+
+					By("checking for NMState in nmstate namespace")
+					nmstateOperatorHandlersReady := func() bool {
+						nmstateHandlerDaemonSet := &v1.DaemonSet{}
+						err := testenv.Client.Get(context.TODO(), types.NamespacedName{Name: NMStateComponent.DaemonSets[0], Namespace: "nmstate"}, nmstateHandlerDaemonSet)
+						if err != nil {
+							return false
+						}
+						return nmstateHandlerDaemonSet.Status.DesiredNumberScheduled == nmstateHandlerDaemonSet.Status.NumberReady
+					}
+					Eventually(func() bool {
+						return nmstateOperatorHandlersReady()
+					}, 5*time.Minute, time.Second).Should(BeTrue(), "Timed out waiting for nmstate-operator daemonset")
+					CheckNMStateOperatorIsReady(5 * time.Minute)
+					By("checking Nmstate is not owned by CNAO")
+					nmstate, err := kubectl.Kubectl("get", "nmstate", "nmstate", "-n", "nmstate", "-o", "yaml")
+					Expect(err).NotTo(HaveOccurred())
+					Expect(nmstate).NotTo(ContainSubstring("ownerReferences"))
 				})
 			})
 		})
