@@ -2,6 +2,7 @@ package test
 
 import (
 	"context"
+	"os"
 	"testing"
 	"time"
 
@@ -10,26 +11,18 @@ import (
 
 	ginkgoreporters "kubevirt.io/qe-tools/pkg/ginkgo-reporters"
 
-	monitoringv1 "github.com/coreos/prometheus-operator/pkg/apis/monitoring/v1"
-	f "github.com/operator-framework/operator-sdk/pkg/test"
-	framework "github.com/operator-framework/operator-sdk/pkg/test"
 	appsv1 "k8s.io/api/apps/v1"
 	"k8s.io/apimachinery/pkg/types"
 
-	"github.com/kubevirt/cluster-network-addons-operator/pkg/apis"
-	cnaov1 "github.com/kubevirt/cluster-network-addons-operator/pkg/apis/networkaddonsoperator/v1"
 	"github.com/kubevirt/cluster-network-addons-operator/pkg/components"
 	. "github.com/kubevirt/cluster-network-addons-operator/test/check"
+	testenv "github.com/kubevirt/cluster-network-addons-operator/test/env"
 	. "github.com/kubevirt/cluster-network-addons-operator/test/operations"
 	cnaoreporter "github.com/kubevirt/cluster-network-addons-operator/test/reporter"
 )
 
 var operatorVersion string
 
-func TestMain(m *testing.M) {
-	f.MainEntry(m)
-}
-
 func TestE2E(t *testing.T) {
 	RegisterFailHandler(Fail)
 	reporters := make([]Reporter, 0)
@@ -42,14 +35,14 @@ func TestE2E(t *testing.T) {
 }
 
 var _ = BeforeSuite(func() {
-	By("Adding custom resource scheme to framework")
-	err := framework.AddToFrameworkScheme(apis.AddToScheme, &cnaov1.NetworkAddonsConfigList{})
-	Expect(err).ToNot(HaveOccurred())
 
-	Expect(framework.AddToFrameworkScheme(monitoringv1.AddToScheme, &monitoringv1.ServiceMonitorList{})).To(Succeed())
-	Expect(framework.AddToFrameworkScheme(monitoringv1.AddToScheme, &monitoringv1.PrometheusRuleList{})).To(Succeed())
+	// Change to root directory some test expect that
+	os.Chdir("../../../")
+
+	testenv.Start()
 
 	By("Detecting operator version")
+	var err error
 	operatorVersion, err = getRunningOperatorVersion()
 	Expect(err).ToNot(HaveOccurred())
 })
@@ -71,7 +64,7 @@ var _ = AfterEach(func() {
 func getRunningOperatorVersion() (string, error) {
 	operatorDep := &appsv1.Deployment{}
 
-	err := framework.Global.Client.Get(context.Background(), types.NamespacedName{Name: components.Name, Namespace: components.Namespace}, operatorDep)
+	err := testenv.Client.Get(context.Background(), types.NamespacedName{Name: components.Name, Namespace: components.Namespace}, operatorDep)
 	if err != nil {
 		return "", err
 	}
